By selecting a data set the user can set all options for working with the gather
function of the tidyr package. The user is able to visualise the impact of the
options set and on return the shiny gadget will return the code required to recreate.
Usage
tidyData(data)
Arguments
data
(Optional) Data frame to be manipulated. If not provided the data from
all data.frame objects in the current environment will be available for selection in the gadget.